function out_table = make_btz_alt_table( vixsample_d, vixsample_m, vixsample_m_off, params)
% function out_table = make_btz_alt_table( vixsample_d, vixsample_m, params)
%  creates table of regression outputs using various specifications all
%  based on predicting future market returns using the btz estimate of vrp
%
%   vixsample_d must be a table including daily mktrf, sigsq_vix,
%   sigsq_both, futrv_0
%   vixsample_m must be a table including sp500ret, rf, vrp_dy, sigsq_both,
%   realvar, futrv_0
%
%   params must include:
%       - nsims, number of simulations to do for standard errors
%       - nlags, number of lags for Newey West

% want stambaugh adjustment throughout
params.adjuststambaugh = true; 

% Replication
vixbtzsample_m = vixsample_m(vixsample_m.month <= 200712,:); 

% Best replication of BTZ I can do, using original data
% 1 month
in.r = log(1+vixbtzsample_m.sp500ret-vixbtzsample_m.rf); 
in.x = vixbtzsample_m.VRP; 
% in.predvar = vixbtzsample_m.sigsq_both; 
in.predvar = vixbtzsample_m.sigsq_rv; 
in.realvar = vixbtzsample_m.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200;
params.nlags = 2; % follow DY = use nfutperiods+1 for NW lags
[ btzorig_ols_col_1, btzorig_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; 
params.nlags = 4; % follow DY = use nfutperiods+1 for NW lags
[ btzorig_ols_col_3, btzorig_wls_col_3 ] = make_vrp_col(in,params); 

% same thing, but with my replicated btz vrp estimate
% 1 month
in.x = vixbtzsample_m.vrp_btz;
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ btzrep_ols_col_1, btzrep_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ btzrep_ols_col_3, btzrep_wls_col_3 ] = make_vrp_col(in,params); 

% Now full monthly sample
% 1 month
in.r = log(1+vixsample_m.sp500ret-vixsample_m.rf); 
in.x = vixsample_m.VRP; 
% in.predvar = vixsample_m.sigsq_both; 
in.predvar = vixsample_m.sigsq_rv; 
in.realvar = vixsample_m.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ btzext_ols_col_1, btzext_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ btzext_ols_col_3, btzext_wls_col_3 ] = make_vrp_col(in,params); 

% offset monthly, 1 month
in.r = vixsample_m_off.sp500ret - vixsample_m_off.rf; 
in.x = vixsample_m_off.vrp_btz; 
in.predvar = vixsample_m_off.sigsq_rv; 
in.realvar = vixsample_m_off.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ btzoff_ols_col_1, btzoff_wls_col_1 ] = make_vrp_col(in,params); 

% offset 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ btzoff_ols_col_3, btzoff_wls_col_3 ] = make_vrp_col(in,params); 

% Now original daily sample
vixbtzsample_d = vixsample_d(vixsample_d.date <= 20071231,:); 

% stick to 21 lags for monthly overlapping
params.nlags = 21; 

% 1 month
in.r = log(1+vixbtzsample_d.sp500ret-vixbtzsample_d.rf); 
in.x = vixbtzsample_d.vrp_btz; 
in.predvar = vixbtzsample_d.sigsq_both; 
in.realvar = vixbtzsample_d.futrv_0; 
params.nfutperiods = 21; params.lhsmultiplier = 1200; 
[ btz_d_ols_col_1, btz_d_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 63; params.lhsmultiplier = 400; 
[ btz_d_ols_col_3, btz_d_wls_col_3 ] = make_vrp_col(in,params); 

% Now full daily sample (still sp500 rets)

% 1 month
in.r = log(1+vixsample_d.sp500ret-vixsample_d.rf); 
in.x = vixsample_d.vrp_btz; 
in.predvar = vixsample_d.sigsq_both; 
in.realvar = vixsample_d.futrv_0; 
params.nfutperiods = 21; params.lhsmultiplier = 1200; 
[ btzext_d_ols_col_1, btzext_d_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 63; params.lhsmultiplier = 400; 
[ btzext_d_ols_col_3, btzext_d_wls_col_3 ] = make_vrp_col(in,params); 

out_table_1 = [ btzorig_ols_col_1 btzorig_wls_col_1 NaN(6,1) ...
    btzrep_ols_col_1 btzrep_wls_col_1 NaN(6,1) ...
    btz_d_ols_col_1 btz_d_wls_col_1 NaN(6,1) ...
    btzext_ols_col_1 btzext_wls_col_1 NaN(6,1) ...
    btzoff_ols_col_1 btzoff_wls_col_1 NaN(6,1) ...
    btzext_d_ols_col_1 btzext_d_wls_col_1 ]; 


out_table_3 = [ btzorig_ols_col_3 btzorig_wls_col_3 NaN(6,1) ...
    btzrep_ols_col_3 btzrep_wls_col_3 NaN(6,1) ...
    btz_d_ols_col_3 btz_d_wls_col_3 NaN(6,1) ...
    btzext_ols_col_3 btzext_wls_col_3 NaN(6,1) ...
    btzoff_ols_col_3 btzoff_wls_col_3 NaN(6,1) ...
    btzext_d_ols_col_3 btzext_d_wls_col_3 ]; 

out_table = [out_table_1; NaN(1,17); out_table_3]; 