function out_table = make_dy_alt_table( vixsample_d, vixsample_m, vixsample_m_off, params)
% function out_table = make_dy_alt_table( vixsample_d, vixsample_m, vixsample_m_off, params)
%  creates table of regression outputs using various specifications all
%  based on predicting future market returns using the dy estimate of vrp
%
%   vixsample_d must be a table including daily mktrf, sigsq_vix,
%   sigsq_both, futrv_0
%   vixsample_m must be a table including sp500ret, rf, vrp_dy, sigsq_both,
%   futrv_0
%
%   params must include:
%       - nsims, number of simulations to do for standard errors
%       - nlags, number of lags for Newey West

% want stambaugh adjustment throughout
params.adjuststambaugh = true; 

% Replication
vixdysample_m = vixsample_m(vixsample_m.month <= 200703,:); 

% Best replication of DY I can do
% 1 month
in.r = vixdysample_m.sp500ret-vixdysample_m.rf; 
in.x = vixdysample_m.vrp_dy; 
% in.predvar = vixdysample_m.sigsq_both; 
in.predvar = vixdysample_m.sigsq_rv; 
in.realvar = vixdysample_m.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200;
params.nlags = 2; % follow DY = use nfutperiods+1 for NW lags
[ dyrep_ols_col_1, dyrep_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; 
params.nlags = 4; % follow DY = use nfutperiods+1 for NW lags

[ dyrep_ols_col_3, dyrep_wls_col_3 ] = make_vrp_col(in,params); 

% same thing, but with log returns
% 1 month
in.r = log(1+vixdysample_m.sp500ret-vixdysample_m.rf);
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ dyreplog_ols_col_1, dyreplog_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ dyreplog_ols_col_3, dyreplog_wls_col_3 ] = make_vrp_col(in,params); 

% Now full monthly sample
% 1 month
in.r = vixsample_m.sp500ret-vixsample_m.rf; 
in.x = vixsample_m.vrp_dy; 
in.predvar = vixsample_m.sigsq_rv; 
in.realvar = vixsample_m.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ dyext_ols_col_1, dyext_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ dyext_ols_col_3, dyext_wls_col_3 ] = make_vrp_col(in,params); 

% offset monthly, 1 month
in.r = vixsample_m_off.sp500ret - vixsample_m_off.rf; 
in.x = vixsample_m_off.vrp_dy; 
in.predvar = vixsample_m_off.sigsq_rv; 
in.realvar = vixsample_m_off.futrv_0; 
params.nfutperiods = 1; params.lhsmultiplier = 1200; params.nlags = 2; 
[ dyoff_ols_col_1, dyoff_wls_col_1 ] = make_vrp_col(in,params); 

% offset 3 months
params.nfutperiods = 3; params.lhsmultiplier = 400; params.nlags = 4; 
[ dyoff_ols_col_3, dyoff_wls_col_3 ] = make_vrp_col(in,params); 

% Now original daily sample
vixdysample_d = vixsample_d(vixsample_d.date <= 20070331,:); 

% 1 month
in.r = log(1+vixdysample_d.sp500ret-vixdysample_d.rf); 
in.x = vixdysample_d.vrp_dy; 
in.predvar = vixdysample_d.sigsq_rv; 
in.realvar = vixdysample_d.futrv_0; 
params.nfutperiods = 21; params.lhsmultiplier = 1200; 
params.nlags = 21; % use 21 lags for overlapping daily
[ dy_d_ols_col_1, dy_d_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 63; params.lhsmultiplier = 400; 
[ dy_d_ols_col_3, dy_d_wls_col_3 ] = make_vrp_col(in,params); 

% Now full daily sample (still sp500 rets)
% 1 month
in.r = log(1+vixsample_d.sp500ret-vixsample_d.rf); 
in.x = vixsample_d.vrp_dy; 
in.predvar = vixsample_d.sigsq_rv; 
in.realvar = vixsample_d.futrv_0; 
params.nfutperiods = 21; params.lhsmultiplier = 1200; 
[ dyext_d_ols_col_1, dyext_d_wls_col_1 ] = make_vrp_col(in,params); 

% 3 months
params.nfutperiods = 63; params.lhsmultiplier = 400; 
[ dyext_d_ols_col_3, dyext_d_wls_col_3 ] = make_vrp_col(in,params); 

out_table_1 = [ dyrep_ols_col_1 dyrep_wls_col_1 NaN(6,1) ...
    dyreplog_ols_col_1 dyreplog_wls_col_1 NaN(6,1) ...
    dy_d_ols_col_1 dy_d_wls_col_1 NaN(6,1) ...
    dyext_ols_col_1 dyext_wls_col_1 NaN(6,1) ...
    dyoff_ols_col_1 dyoff_wls_col_1 NaN(6,1) ...
    dyext_d_ols_col_1 dyext_d_wls_col_1 ]; 

out_table_3 = [ dyrep_ols_col_3 dyrep_wls_col_3 NaN(6,1) ...
    dyreplog_ols_col_3 dyreplog_wls_col_3 NaN(6,1) ...
    dy_d_ols_col_3 dy_d_wls_col_3 NaN(6,1) ...
    dyext_ols_col_3 dyext_wls_col_3 NaN(6,1) ...
    dyoff_ols_col_3 dyoff_wls_col_3 NaN(6,1) ...
    dyext_d_ols_col_3 dyext_d_wls_col_3 ]; 


out_table = [out_table_1; NaN(1,17); out_table_3]; 