function [ ols_table_m, wls_table_m, ols_table_d, wls_table_d ] = make_intlvrp_table(params)

load([params.data_folder 'international_vrp_data.mat']); 

% Parameters 
params.adjuststambaugh = 1; 

% month range for monthly samples
min_month = 200001; 
max_month = 201312; 

% day range for daily samples
min_date = 20000101; 
max_date = 20131231; 

% set of nfutmonths
nfutmonths = [ 1 2 3 4 5 6 9 12 ]; 

% set of nfutdays
nfutdays = nfutmonths*21; 

ols_table_m = NaN(21,length(nfutmonths));
wls_table_m = NaN(21,length(nfutmonths));

ols_table_d = NaN(21,length(nfutmonths));
wls_table_d = NaN(21,length(nfutmonths));

% loop through countries
for c = 1:7
if( c == 1 )
    data = netherlands;
    data.rf(isnan(data.rf),1) = data.rf_cb(isnan(data.rf),1); 
elseif( c == 2 )
    data = belgium;
    data.rf(isnan(data.rf),1) = data.rf_cb(isnan(data.rf),1); 
elseif( c == 3 )
    data = france;
    data.rf(isnan(data.rf),1) = data.rf_cb(isnan(data.rf),1); 
elseif( c == 4 )
    data = germany;
    data.rf(isnan(data.rf),1) = data.rf_cb(isnan(data.rf),1); 
elseif( c == 5 )
    data = uk;
elseif( c == 6 )
    data = japan;
elseif (c == 7 ) 
    data = switzerland;    
end

% scale rf so it's annualized but not percent
data.rf = data.rf/100; 

%daily one
data.dailyrf = (1+data.rf).^(1/252)-1; 

% First, monthly version
data.month = floor(data.date/100); 
data.r_index = log(1+[0; data.s_index(2:end,1)./data.s_index(1:end-1,1)-1] - data.dailyrf); 

% Compute monthly index returns and realized var
umonths = unique(data.month);

% cut down to proper range
umonths = umonths(umonths >= min_month & umonths <= max_month,1); 
n_umonths = length(umonths); 

% This table with have monthly variances for IV and RV!
data_m = array2table([umonths NaN(n_umonths,4)],'VariableNames', ...
    {'month','r_index','IV','RV','rf'}); 

for i = 1:n_umonths
    % compute monthly returns, RV, IV, and rf
    data_m.r_index(i,1) = sum(data.r_index(data.month == umonths(i,1),1)); 
    data_m.RV(i,1) = sum(data.r_index(data.month == umonths(i,1),1).^2); 
    data_m.IV(i,1) = (1/12)*(data.vol_index( ...
        find(data.month == umonths(i,1) & ~isnan(data.vol_index),1,'last'),1)/100).^2; 
end

% x is the country-specific VRP. BTZ scaling calls for multiplying monthly
% vars by 10000
x = (10000)*(data_m.IV-data_m.RV); %

% compute sigsq
coeff_const = [ ones(n_umonths-1,1) data_m.IV(1:end-1,1) ] \ data_m.RV(2:end,1); 
coeff_noconst = data_m.IV(1:end-1,1) \ data_m.RV(2:end,1); 

if( sum( coeff_const < 0 ) == 0 )
    sigsq = [ ones(n_umonths,1) data_m.IV ]*coeff_const; 
else
    sigsq = data_m.IV*coeff_noconst; 
end

% loop through nfutmonths
for i = 1:length(nfutmonths)
    params.nfutperiods = nfutmonths(i); 
    params.lhsmultiplier = 100*12/nfutmonths(i); 
    in.r = data_m.r_index; 
    in.x = x; 
    in.predvar = sigsq; 
    in.realvar = data_m.RV; 
    [ ols_col, wls_col ] = make_intlvrp_col(in,params);

    ols_table_m(3*(c-1)+1:3*(c-1)+3,i) = ols_col; 
    wls_table_m(3*(c-1)+1:3*(c-1)+3,i) = wls_col; 
    
    fprintf('   Done with %d of %d nfutmonths\n',i,length(nfutmonths)); 
end

% Now, daily version
% cut down to proper range
data = data(data.date >= min_date & data.date <= max_date,:);

% compute RV and IV
data.RV = [NaN(20,1); conv(data.r_index.^2,ones(1,21),'valid')]; 
% data.RV = [NaN(20,1); conv(log(1+data.r_index).^2,ones(1,21),'valid')]; 
data.IV = (1/12)*(data.vol_index/100).^2; 

% Compute x, focus on data where x ~isnan
x = (10000)*(data.IV-data.RV); 

xnan = isnan(x); 
data = data(~xnan,:); 
x = x(~xnan,1); 

% compute sigsq
n_data = height(data); 
coeff_const = [ ones(n_data-1,1) data.IV(1:end-1,1) ] \ data.r_index(2:end,1).^2; 
coeff_noconst = data.IV(1:end-1,1) \ data.r_index(2:end,1).^2; 

if( sum( coeff_const < 0 ) == 0 )
    sigsq = [ ones(n_data,1) data.IV ]*coeff_const; 
else
    sigsq = data.IV*coeff_noconst; 
end

% loop through nfutdays
for i = 1:length(nfutdays)
    params.nfutperiods = nfutdays(i); 
    params.lhsmultiplier = 100*252/nfutdays(i); 
    in.r = data.r_index; 
    in.x = x; 
    in.predvar = sigsq; 
    in.realvar = sigsq; 
    [ ols_col, wls_col ] = make_intlvrp_col(in,params);
    
%     lhs = exp(conv(data_m.r

    ols_table_d(3*(c-1)+1:3*(c-1)+3,i) = ols_col; 
    wls_table_d(3*(c-1)+1:3*(c-1)+3,i) = wls_col; 
    
    fprintf('   Done with %d of %d nfutdays\n',i,length(nfutdays)); 
end

fprintf('Done with %d of 7 countries\n',c); 

end % end of loop through countries

