function c = make_var_prediction_col(LHS,RHS,coeffrows,numrows)
% function c = make_var_prediction_col(LHS,RHS,coeffrows,numrows)
% creates column c = numrows x (1 or 2) column for table with realized
%                   variance on the LHS
%                   First column has a constant, second returned iff
%                   constant is negative
% Inputs: LHS and RHS of regression
% coeffrows = vector of rows in c that contain coefficients; first entry
% contains constant by default

% cut out NaNs
selector = ~isnan(LHS) & sum(isnan(RHS),2) == 0; 
LHS = LHS(selector,1); 
RHS = RHS(selector,:); 

T = length(LHS); 

% Newey West (1987) number of lags
nlags = 12; 

% Compute regression with a constant
[bv_const, sebv_const, ~, R2vadj_const, ~, ~] = olsgmm(LHS,RHS,nlags,1);

c = NaN(numrows,1); 

c(coeffrows,1) = bv_const;
c(coeffrows+1,1) = sebv_const; 
c(end,1) = R2vadj_const;

% scale constant by 100 for readability
c(1:2,1) = 100*c(1:2,1); 
