function out_table = make_vrp_table( vixsample_d, vrp, params )
%function out_table = make_vrp_table( vixsample_d, vrp, params )
%  creates table of regression outputs using passed vrp to predict market
%  returns
%
%   vixsample_d must be a table including daily mktrf, sigsq_vix,
%   sigsq_both, realvar
%   vrp must be a vector with same length as vixsample_d
%   paras must include:
%       - allnfutperiods, vector of forecast horizons to try. will do ols,
%       wls_vix, and wls_vixf for each
%       - lhsmultipliers, vector of multiplies to use, one for each of
%       allnfutperiods
%       - nsims, number of simulations to do for standard errors
%       - nlags, number of lags for Newey West

out_table = []; 

for i = 1:length(params.allnfutperiods)
    params.nfutperiods = params.allnfutperiods(i); 
    params.lhsmultiplier = params.lhsmultipliers(i); 
    params.adjuststambaugh = 1; 
    
    % Compute the three columns
    in.r = log(1+vixsample_d.mktrf); 
    in.x = vrp; 
    in.realvar = vixsample_d.futrv_0; 
    
%     in_vixonly = in;
%     in_vixonly.predvar = vixsample_d.sigsq_vix; 
    in_rv = in; 
    in_rv.predvar = vixsample_d.sigsq_rv; 
    
    in_both = in;    
    in_both.predvar = vixsample_d.sigsq_both; 
    
    [ ols_col, wlsrv_col ] = make_vrp_col(in_rv,params); 
    [ ~, wlsboth_col ] = make_vrp_col(in_both,params); 
    
    out_table_addition = [ ols_col wlsrv_col wlsboth_col ]; 
    out_table = [out_table out_table_addition ]; 
    if( i < length(params.allnfutperiods) )
        out_table = [ out_table NaN(6,1) ]; 
    end
end