function [coeff, SE, rsq, rsq_adj, v, firststage] = wlsev(lhs,rhs,sigsq,lags,se_type,realvar)
% [coeff, SE, rsq, rsq_adj, v, firststage] = wlsev(lhs,rhs,sigsq,lags,se_type,realvar)
% Requires lhs be T x 1, RHS be T x K
%
% lhs and realvar observed after rhs&sigsq, which are observed at same time
%
% lags = number of lags to use for SEs
%
%  se_type: 1 for newey-west 
%           0 for hansen-hodrick
%          -1 skips standard error computations. This speeds things up a lot
%
% if you pass realvar, does first stage regression of realvar on sigsq,
% which can have multiple columns
%
% if not, it uses sigsq directly as regression weights, which must have
% single column

T = size(lhs,1); 
N = size(lhs,2); 
K = size(rhs,2); 

if( nargin == 6)
% In this case, do first-stage regression: realvar = a + b sigsq + delta, constrained so
% sigsqhat > 0

% First stage regression
nsigsq = size(sigsq,2); 
options = optimset('algorithm','interior-point','display','none'); coeff_0 = [mean(realvar); zeros(nsigsq,1)]; 
predvar_coeff = lsqlin([ones(T,1) sigsq ],realvar,[],[],[],[],zeros(nsigsq+1,1),[],coeff_0,options); 
predvar = [ones(T,1) sigsq ]*predvar_coeff; 

firststage.predvar_coeff = predvar_coeff; 
firststage.predvar = predvar; 

% Second-stage regression: lhs = alpha + beta x + epsilon, estimated to
% minimize sum (epsilon^2)/predvar^2

[coeff, SE, ~, ~, v, ~] = olsgmm(lhs./sqrt(predvar),rhs ./ (sqrt(predvar)*ones(1,K)),lags,se_type); 

else
% In this case, do not use first-stage regression and use sigsq as provided
firststage = 'not used'; 

[coeff, SE, ~, ~, v, ~] = olsgmm(lhs./(sqrt(sigsq)*ones(1,N)),rhs ./ (sqrt(sigsq)*ones(1,K)),lags,se_type); 
end

% Now need to compute R^2. Can't use above since it modifies LHS and RHS
epsilon = lhs-rhs*coeff;
meanepssq = mean(epsilon.^2);
vary = var(lhs,1);

rsq = (1-meanepssq/vary)';
rsq_adj = (1 - (meanepssq./vary)*(T-1)/(T-K));